# Active Redis

Active Redis is a helper class, that helps you use rails helpers with [Datamapper](http://datamapper.org/) on top of the [Datamapper Redis](https://github.com/arbarlow/dm-redis-adapter) adapter.

With this gem, you can easily have Redis in Rails and still user form_for and the path_helpers and pretty much everything else..


# Installing

There are some dependencies, heres a gem file for a typical app. 
Note the use of my git repo's as they contain certain patches to get it all working

	source 'http://rubygems.org'

	gem 'rails'
	gem 'mongrel', '>= 1.2.0.pre2'

	gem 'dm-core',           '~> 1.0.2'
	gem 'dm-redis-adapter', :git => "git@github.com:arbarlow/dm-redis-adapter.git"
	gem 'dm-serializer',     '~> 1.0.2'
	gem 'dm-timestamps',     '~> 1.0.2'
	gem 'dm-validations',    '~> 1.0.2'
	gem 'dm-devise',         '~> 1.1.4'

	gem 'active-redis', :git => "git@github.com:arbarlow/active-redis.git"
	gem "dm-paperclip", :git => "git@github.com:arbarlow/dm-paperclip.git"
	gem 's3'

You need an initialiser that looks like this...

	DataMapper.setup(:default, {:adapter  => "redis"})

I suggest you now read [Datamapper](http://datamapper.org/) and the [Datamapper Redis](https://github.com/arbarlow/dm-redis-adapter) docs, to see about finds etc.


# Compatibility

Thats right, you've guessed it, this can work with devise and paperclip and s3! Its all there. Please do write more.

# Usage

A typical model in rails might look like this...

	class Post < ActiveRedis
  
	  belongs_to :user
  
	  has n, :comments

	  property :param_name,   String, :index => true
	  property :title,        String
	  property :body,         Text
	  property :created_at,   DateTime

	end

This would give you URL's like '/posts/1' to get pretty URL's add the following to your model..

	before :save, :create_param_name

	def create_param_name
	  self.param_name = self.title.parameterize
	  true
	end

	def to_param
	  param_name
	end


# Paperclip

As promised, paperclip goodness, using my port of the gem, it also works in 1.9.2 and using the s3 gem means, European buckets!

In an initialiser, configure paperclip..

	Paperclip.configure do |config|
	  config.root               = Rails.root # the application root to anchor relative urls (defaults to Dir.pwd)
	  config.env                = Rails.env  # server env support, defaults to ENV['RACK_ENV'] or 'development'
	  #config.use_dm_validations = true       # validate attachment sizes and such, defaults to false
	  #config.processors_path    = 'lib/pc'   # relative path to look for processors, defaults to 'lib/paperclip_processors'
	end

And then in your model

	include Paperclip::Resource

	has_attached_file :picture, :styles => { :medium => "300x300>", :thumb => "100x100>" }, 
	                  :storage => :s3,
	                  :s3_credentials => "#{Rails.root.to_s}/config/aws.yml",
	                  :path => "posts/:id/:style.:extension",
	                  :default_url => "/paperclips/posts/:style/missing.png"

You can either use file storage, or the aws/s3 gem, or the s3 gem, which will let you use European buckets..

To use the s3 gem with your application, you need to have an initialiser which attaches the s3 gem to paperclip

You can get this here [Paperclip S3](https://github.com/arbarlow/paperclip-s3). Put this in an initialiser..


# Devise

Yup, authenticate via Redis.

Firstly. Make a database.yml. But just put some rubbish in there. Its not needed, but [Datamapper Devise](https://github.com/jm81/dm-devise) needs one to run the generator.
Follow the usual devise steps and your good to go!

